/*
 * Copyright 2010-2012 Craig S. Dickson (http://craigsdickson.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.squeakysand.jcr;

import javax.jcr.Item;

public interface ItemFilter {

    boolean filter(Item item);

    public static final ItemFilter ACCEPT_ALL = new ItemFilter() {

        @Override
        public boolean filter(Item item) {
            return true;
        }

    };

    public static final ItemFilter ACCEPT_NONE = new ItemFilter() {

        @Override
        public boolean filter(Item item) {
            return false;
        }

    };

    public static final ItemFilter NODES_ONLY = new ItemFilter() {

        @Override
        public boolean filter(Item item) {
            return item.isNode();
        }

    };

    public static final ItemFilter PROPERTIES_ONLY = new ItemFilter() {

        @Override
        public boolean filter(Item item) {
            return !item.isNode();
        }

    };

    public static final ItemFilter MODIFIED_ONLY = new ItemFilter() {

        @Override
        public boolean filter(Item item) {
            return item.isModified();
        }

    };

    public static final ItemFilter NEW_ONLY = new ItemFilter() {

        @Override
        public boolean filter(Item item) {
            return item.isNew();
        }

    };

}
