/*
 * Copyright 2010-2012 Craig S. Dickson (http://craigsdickson.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.squeakysand.jcr;

import javax.jcr.Property;
import javax.jcr.PropertyType;

public class SimpleProperty extends DelegatingProperty {

    public static enum Type {

        STRING(PropertyType.STRING),
        BINARY(PropertyType.BINARY),
        LONG(PropertyType.LONG),
        DOUBLE(PropertyType.DOUBLE),
        DECIMAL(PropertyType.DECIMAL),
        DATE(PropertyType.DATE),
        BOOLEAN(PropertyType.BOOLEAN),
        NAME(PropertyType.NAME),
        PATH(PropertyType.PATH),
        REFERENCE(PropertyType.REFERENCE),
        WEAKREFERENCE(PropertyType.WEAKREFERENCE),
        URI(PropertyType.URI),
        UNDEFINED(PropertyType.UNDEFINED);

        public static Type getType(int id) {
            Type result = null;
            for (Type type : Type.values()) {
                if (type.getId() == id) {
                    result = type;
                    break;
                }
            }
            if (result == null) {
                result = UNDEFINED;
            }
            return result;
        }

        private int id;

        Type(int id) {
            this.id = id;
        }

        public int getId() {
            return id;
        }

    }

    public SimpleProperty(Property property) {
        super(property);
    }

}
